@@ -24,21 +24,21 @@ public:
     FTDCParser() : keepChunkStruct(false) {};
 
     bson_reader_t* open(std::string file_path);
-    int parseFiles(std::vector<std::string> &file_paths,  bool metadata, bool metric_names);
+    int parseFiles(std::vector<std::string> const *file_paths,  bool metadata, bool metric_names);
     int parseFiles(std::string file_paths,  bool metadata, bool metric_names);
 
     int parseInfoChunk (const bson_t *bson);
     std::vector<std::string> getMetricsNamesPrefixed(std::string prefix) ;
     std::vector<std::string> getMetricsNames();
 
-    std::vector<uint64_t >* getMetric(std::string name) { return dataSet.getMetric(name);}
+    Dataset::MetricsPtr getMetric(std::string   name) ;
  
     size_t getMetricLength() { return dataSet.getMetricLength(); }
     std::vector<Chunk*> getChunks() { return dataSet.getChunkVector(); }
 
     std::vector<std::string> getMetadata() { return metadata; }
 
-    std::map<std::string,  std::vector<uint64_t >*> getHashMetrics() { return dataSet.getHashMetrics(); }
+    std::map<std::string,  Dataset::MetricsPtr> getHashMetrics() { return dataSet.getHashMetrics(); }
 
     void keepChunkStructures(bool b) { keepChunkStruct = b; }
 
