@@ -122,19 +122,9 @@ struct ParserClass {
     }
 
     py::array_t<uint64_t>  getMetricListAsNumpyMatrix(std::vector<std::string> metricNames, bool transposed=Py_False) {
-        py::array_t<uint64_t , py::array::c_style> a;
 
         if (transposed) {
-            a.resize({(int) pParser->getMetricLength(), (int) metricNames.size()});
-            auto r = a.mutable_unchecked();
-            for (int i=0; i<pParser->getMetricLength(); ++i) {
-                for (int j=0; j<metricNames.size(); ++j) {
-                    auto element = pParser->getMetric(metricNames[j]);
-                    r(i, j) = element->at(i);
-                }
-            }
-        }
-        else {
+            py::array_t<uint64_t, py::array::f_style> a;
             a.resize({(int) metricNames.size(), (int) pParser->getMetricLength()});
             auto r = a.mutable_unchecked();
             for (py::ssize_t i = 0; i < r.shape(0); i++) {
@@ -142,8 +132,21 @@ struct ParserClass {
                 for (py::ssize_t j = 0; j < r.shape(1); j++)
                     r(i, j) = element->at(j);
             }
+            return a;
         }
-        return a;
+        else {
+            py::array_t<uint64_t, py::array::c_style> a;
+
+            a.resize({(int) metricNames.size(), (int) pParser->getMetricLength()});
+            auto r = a.mutable_unchecked();
+            for (py::ssize_t i = 0; i < r.shape(0); i++) {
+                auto element = pParser->getMetric(metricNames[i]);
+                for (py::ssize_t j = 0; j < r.shape(1); j++)
+                    r(i, j) = element->at(j);
+            }
+            return a;
+        }
+
     }
 
     py::array_t<uint64_t> miau(std::vector<std::string> metricNames) {
